@@ -1,18 +1,12 @@
 #
-# $Id: LWP.pm,v 1.50 1997/06/10 11:07:19 aas Exp $
+# $Id: LWP.pm,v 1.53 1997/08/06 09:08:57 aas Exp $
 
 package LWP;
 
-require Exporter;
-@ISA=qw(Exporter);  # for version number checking only, since we really
-                    # don't export anything.  This will noe be neccessary
-                    # when perl5.004 is out.
-
-$VERSION = "5.10";
-
+$VERSION = "5.12";
 sub Version { $VERSION; }
 
-require 5.002;
+require 5.004;
 require LWP::UserAgent;  # this should load everything you need
 
 1;
